@@ -2,8 +2,7 @@ package Syntax::Highlight::Engine::Simple::HTML;
 use strict;
 use warnings;
 use base qw(Syntax::Highlight::Engine::Simple);
-#use version;
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 ### ----------------------------------------------------------------------------
 ### set syntax
@@ -52,11 +51,11 @@ Syntax::Highlight::Engine::Simple::HTML - (EXPERIMENTAL)HTML code highlighting c
 
 =head1 VERSION
 
-This document describes Syntax::Highlight::Engine::Simple::HTML version 0.0.1
+This document describes Syntax::Highlight::Engine::Simple::HTML
 
 =head1 SYNOPSIS
 
-Constractor
+Constructor
 
 	use Syntax::Highlight::Engine::Simple::HTML;
 	
@@ -107,7 +106,7 @@ File type. This argument causes specific sub class to be loaded.
 
 =item html_escape_code_ref
 
-HTML escape code ref. Default subroutine escapes 3 charactors '&', '<' and '>'.
+HTML escape code ref. Default subroutine escapes 3 characters '&', '<' and '>'.
 
 =back
 
@@ -144,7 +143,7 @@ String.
 
 =item tab_width
 
-Tab width for tab-space conversion. -1 for disable it. -1 is the defult.
+Tab width for tab-space conversion. -1 for disable it. -1 is the default.
 
 =back
 
@@ -166,7 +165,7 @@ File name.
 
 =item tab_width
 
-Tab width for tab-space conversion. -1 for disable it. -1 is the defult.
+Tab width for tab-space conversion. -1 for disable it. -1 is the default.
 
 =item encode
 
@@ -192,7 +191,7 @@ Returns the class names in array.
 
 =head2 setSyntax
 
-This is a method for initializing the syntax. It is called by constractor so
+This is a method for initializing the syntax. It is called by constructor so
 you may not have to call it manually.
 
 =head1 Example
@@ -228,7 +227,7 @@ Here is a sample of CSS.
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-Syntax::Highlight::Engine::Simple::HTML requires no configuration files or environment variables. Specific language syntax can be defined with sub classes and loaded in constractor if you give it the type argument.
+Syntax::Highlight::Engine::Simple::HTML requires no configuration files or environment variables. Specific language syntax can be defined with sub classes and loaded in constructor if you give it the type argument.
 
 =head1 DEPENDENCIES
 
